@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = '0.07'; # Set automatically by milla
+our $VERSION = '0.08'; # Set automatically by milla
 
 use parent qw( Plack::Middleware );
 
@@ -71,7 +71,7 @@ sub call {
 			HTTP::Exception::400->throw(status_message => "Parser error: $@") if $@;
 
 			# Parse encode type from parameters
-			if ($resp && ref $resp eq 'HASH' && exists $resp->{enctype}){
+			if ($resp && ref $resp && exists $resp->{enctype}){
 				my $contentType = delete $resp->{enctype};
 				my $format =  delete $resp->{format};
 
@@ -93,6 +93,7 @@ sub call {
 						}else{
 							$query_value = "$outParam=" . $resp->mixed->{$param};
 						}
+						$data->{$param} = $resp->mixed->{$param};
 						$env->{QUERY_STRING} .= ( $env->{QUERY_STRING} eq ''?'':'&' ) . $query_value;
 						delete $resp->{$param};
 					}
